import { ComponentRef } from '@angular/core';
import { NgfModalBackdrop } from './modal-backdrop';
import { NgfModalWindow } from './modal-window';
import { ContentRef } from './content-ref';
/**
 * A reference to an active (currently opened) modal. Instances of this class
 * can be injected into components passed as modal content.
 */
export declare class NgfActiveModal {
    /**
     * Can be used to close a modal, passing an optional result.
     */
    close(result?: any): void;
    /**
     * Can be used to dismiss a modal, passing an optional reason.
     */
    dismiss(reason?: any): void;
}
/**
 * A reference to a newly opened modal.
 */
export declare class NgfModalRef {
    private _windowCmptRef;
    private _contentRef;
    private _backdropCmptRef;
    private _resolve;
    private _reject;
    /**
     * The instance of component used as modal's content.
     * Undefined when a TemplateRef is used as modal's content.
     */
    componentInstance: any;
    /**
     * A promise that is resolved when a modal is closed and rejected when a modal is dismissed.
     */
    result: Promise<any>;
    constructor(_windowCmptRef: ComponentRef<NgfModalWindow>, _contentRef: ContentRef, _backdropCmptRef?: ComponentRef<NgfModalBackdrop>);
    /**
     * Can be used to close a modal, passing an optional result.
     */
    close(result?: any): void;
    /**
     * Can be used to dismiss a modal, passing an optional reason.
     */
    dismiss(reason?: any): void;
    private _removeModalElements();
}
